@@ -1,10 +1,5 @@
 package LWP::UserAgent::Plugin::Retry;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-08-13'; # DATE
-our $DIST = 'LWP-UserAgent-Plugin-Retry'; # DIST
-our $VERSION = '0.004'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
@@ -12,6 +7,11 @@ use Log::ger;
 
 use Time::HiRes qw(sleep);
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2024-07-17'; # DATE
+our $DIST = 'LWP-UserAgent-Plugin-Retry'; # DIST
+our $VERSION = '0.005'; # VERSION
+
 sub after_request {
     my ($class, $r) = @_;
 
@@ -111,7 +111,7 @@ LWP::UserAgent::Plugin::Retry - Retry failed requests
 
 =head1 VERSION
 
-This document describes version 0.004 of LWP::UserAgent::Plugin::Retry (from Perl distribution LWP-UserAgent-Plugin-Retry), released on 2021-08-13.
+This document describes version 0.005 of LWP::UserAgent::Plugin::Retry (from Perl distribution LWP-UserAgent-Plugin-Retry), released on 2024-07-17.
 
 =head1 SYNOPSIS
 
@@ -159,14 +159,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/LWP-UserAg
 
 Source repository is at L<https://github.com/perlancar/perl-LWP-UserAgent-Plugin-Retry>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=LWP-UserAgent-Plugin-Retry>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<LWP::UserAgent::Plugin>
@@ -193,15 +185,24 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2024, 2021, 2020 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=LWP-UserAgent-Plugin-Retry>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
